Add additional meta variables in the logging context on top of the ones
that are readily collected in get_logger_meta_variables
function. It might be needed to add some other metadata specific to the
logging usage - that goal is served by this function.
.add_meta_variables(
additional_fields = NULL,
log_level = NULL,
namespace = NA_character_,
.logcall = sys.call(),
.topcall = sys.call(-1),
.topenv = parent.frame()
)Returns a vector of collected meta-data. It is used in defining the
log_layout function.
A named vector of type list with key-value pairs of
additional meta data which needs to be added in logging context on top of
log_fields. The respective value of each key is expected to be of
length 1. It is NULL by default.
log level as per log_levels
string referring to the logger environment / config to be used to override the target of the message record to be used instead of the default namespace, which is defined by the R package name from which the logger was called, and falls back to a common, global namespace.
the logging call being evaluated (useful in formatters and layouts when you want to have access to the raw, unevaluated R expression)
R expression from which the logging function was called (useful in formatters and layouts to extract the calling function's name or arguments)
original frame of the .topcall calling function where the formatter function will be evaluated and that is used to look up the namespace as well via logger:::top_env_name