Learn R Programming

azlogr (version 0.0.6)

get_log_config: Get configuration value

Description

Get the configuration value of a specific key which was set (or not set) using set_log_config function. If nothing was set, then it reuses the default value defined in the function signature of set_log_config function.

Usage

get_log_config(key = NULL)

Value

Returns the respective configuration value of the given key. If key is NULL, then all the configuration values will be returned together as a list.

Arguments

key

Specify the key whose value needs to be extracted. NULL implies no specific key, rather all of them to be extracted at once.

Examples

Run this code
  # Get configuration value without setting anything
  get_log_config("log_to_azure")
  # Set some configuration first and then get the respective values
  set_log_config(enforce_tz_utc = FALSE, log_to_azure = FALSE)
  get_log_config("enforce_tz_utc")
  get_log_config("log_to_azure")
  # Reset the values
  set_log_config()
  get_log_config("log_to_azure")

  # Extract list of all configurations
  get_log_config()

Run the code above in your browser using DataLab